<?php
/**
 * Copyright (C) 2021 Inuvika Inc.
 * https://www.inuvika.com
 *
 * All rights reserved
 */


function usage($exit_code=1) {
	global $argv;
	echo("Usage: $argv[0] service_url method_name [args...]".PHP_EOL);
	echo("  service_url: [http[s]://]login:password@sm_host".PHP_EOL);
	echo("  method: the name of the API method to call".PHP_EOL);
	echo("  args: one or more argument(s) to give to the API method. Each argument will be read as JSON format".PHP_EOL);
	exit($exit_code);
}

$options = getopt('h', ['help']);
if (array_key_exists('h', $options) || array_key_exists('help', $options)) {
	usage(0);
}

$pos_args = array_slice($argv, 1);
if (count($pos_args) < 2) {
	echo('Not enough command line arguments'.PHP_EOL);
	usage();
}

$service_url = array_shift($pos_args);
if (strstr($service_url, '://') === false) {
	$service_url = 'https://'.$service_url;
}

$service_url = parse_url($service_url);
foreach (['user', 'pass', 'host'] as $item) {
	if (!isset($service_url[$item])) {
		echo('Invalid format for service_url'.PHP_EOL);
		usage();
	}
}

$method = array_shift($pos_args);
$mathod_args = [];
foreach ($pos_args as $item) {
	$value = json_decode($item, true);
	if ($value===null && $item!='null') {
		if (strlen($item) < 64 && strstr($item, '[')===false && strstr($item, '{')===false) {
			$value = json_decode('"'.$item.'"', true);
		}
	}

	if ($value===null && $item!='null') {
		echo('Invalid format for argument '.$item.PHP_EOL);
		usage();
	}

	$mathod_args []= $value;
}

$service = new SoapClient(
	$service_url['scheme'].'://'.$service_url['host'].'/ovd/service/admin/wsdl',
	[
		'login' => $service_url['user'],
		'password' => $service_url['pass'],
		'location' => $service_url['scheme'].'://'.$service_url['host'].'/ovd/service/admin',
		'stream_context' => stream_context_create([
			'ssl' => [
				'verify_peer' => false,
				'verify_peer_name' => false,
				'allow_self_signed' => true
			],
		]),
	]
);

$ret = $service->__call($method, $mathod_args);
echo(json_encode($ret, JSON_PRETTY_PRINT).PHP_EOL);
exit(0);