#! /usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright (C) 2021 Inuvika Inc.
# https://www.inuvika.com
#
# All rights reserved
#

import argparse
import json
import requests
import sys
from urllib import parse

if __name__ == "__main__":
	parser = argparse.ArgumentParser("Call the Admin API from json args, return json content")
	parser.add_argument("service_url", help="[http[s]://]login:password@sm_host")
	parser.add_argument("method", help="The name of the API method to call")
	parser.add_argument("arguments", nargs="*", help="One of more argument to give to the API method. Each argument will be read as JSON format")
	args = parser.parse_args()

	if "://" not in args.service_url:
		args.service_url = "https://"+args.service_url

	service_url = parse.urlparse(args.service_url)
	if not service_url.hostname or not service_url.username or not service_url.password:
		print('Invalid format for service_url')
		parser.print_help()
		sys.exit(1)

	method_args = []
	for item in args.arguments:
		try:
			method_args.append(json.loads(item))
		except ValueError:
			if "[" not in item and "{" not in item:
				try:
					method_args.append(json.loads('"{}"'.format(item)))
				except ValueError:
					print("Invalid json format for argument:", item)
					parser.print_help()
					sys.exit(2)

	kwargs = {
		"auth": (service_url.username, service_url.password),
		"verify": False,
	}

	if method_args:
		kwargs["json"] = {"args": method_args}

	ret = requests.post(
		"https://{host}/ovd/service/admin/{function}".format(
			host = service_url.hostname,
			function = args.method,
		),
		**kwargs
	)

	print(json.dumps(ret.json(), indent=4, separators=(',', ': ')))
